Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(102)

Unified Diff: chrome/browser/ui/webui/options/extension_settings_handler.h

Issue 9703039: Extensions: Don't pass the selected unpacked extension path from JS to C++ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/options/extension_settings_handler.h
diff --git a/chrome/browser/ui/webui/options/extension_settings_handler.h b/chrome/browser/ui/webui/options/extension_settings_handler.h
index 2fbf7c3bbb4f66c1250cfa241bcbe7c185225acd..732bfd5f8163511a9c61a60dcb6ef10c01dd4f43 100644
--- a/chrome/browser/ui/webui/options/extension_settings_handler.h
+++ b/chrome/browser/ui/webui/options/extension_settings_handler.h
@@ -66,10 +66,31 @@ class ExtensionSettingsHandler : public OptionsPageUIHandler,
bool enabled,
bool terminated);
- // ContentScript JSON Struct for page. (static for ease of testing).
- static base::DictionaryValue* CreateContentScriptDetailValue(
- const UserScript& script,
- const FilePath& extension_path);
+ // OptionsUIHandler implementation.
+ virtual void GetLocalizedValues(
+ base::DictionaryValue* localized_strings) OVERRIDE;
+ virtual void Initialize() OVERRIDE;
+
+ private:
+ // WebUIMessageHandler implementation.
+ virtual void RegisterMessages() OVERRIDE;
+
+ // SelectFileDialog::Listener implementation.
+ virtual void FileSelected(const FilePath& path,
+ int index, void* params) OVERRIDE;
+ virtual void MultiFilesSelected(
+ const std::vector<FilePath>& files, void* params) OVERRIDE;
+ virtual void FileSelectionCanceled(void* params) OVERRIDE {}
+
+ // content::NotificationObserver implementation.
+ virtual void Observe(int type,
+ const content::NotificationSource& source,
+ const content::NotificationDetails& details) OVERRIDE;
+
+ // ExtensionUninstallDialog::Delegate implementation, used for receiving
+ // notification about uninstall confirmation dialog selections.
+ virtual void ExtensionUninstallAccepted() OVERRIDE;
+ virtual void ExtensionUninstallCanceled() OVERRIDE;
// Callback for "requestExtensionsData" message.
void HandleRequestExtensionsData(const base::ListValue* args);
@@ -101,20 +122,14 @@ class ExtensionSettingsHandler : public OptionsPageUIHandler,
// Callback for "showButton" message.
void HandleShowButtonMessage(const base::ListValue* args);
- // Callback for "load" message.
- void HandleLoadMessage(const base::ListValue* args);
-
- // Callback for "pack" message.
- void HandlePackMessage(const base::ListValue* args);
-
// Callback for "autoupdate" message.
void HandleAutoUpdateMessage(const base::ListValue* args);
- // Utility for calling javascript window.alert in the page.
- void ShowAlert(const std::string& message);
+ // Callback for "loadUnpackedExtension" message.
+ void HandleLoadUnpackedExtensionMessage(const base::ListValue* args);
- // Callback for "selectFilePath" message.
- void HandleSelectFilePathMessage(const base::ListValue* args);
+ // Utility for calling JavaScript window.alert in the page.
+ void ShowAlert(const std::string& message);
// Utility for callbacks that get an extension ID as the sole argument.
const Extension* GetExtension(const base::ListValue* args);
@@ -125,33 +140,7 @@ class ExtensionSettingsHandler : public OptionsPageUIHandler,
// Register for notifications that we need to reload the page.
void MaybeRegisterForNotifications();
- // SelectFileDialog::Listener
- virtual void FileSelected(const FilePath& path,
- int index, void* params) OVERRIDE;
- virtual void MultiFilesSelected(
- const std::vector<FilePath>& files, void* params) OVERRIDE;
- virtual void FileSelectionCanceled(void* params) OVERRIDE {}
-
- // WebUIMessageHandler implementation.
- virtual void RegisterMessages() OVERRIDE;
-
- // OptionsUIHandler implementation.
- virtual void GetLocalizedValues(
- base::DictionaryValue* localized_strings) OVERRIDE;
- virtual void Initialize() OVERRIDE;
-
- // content::NotificationObserver implementation.
- virtual void Observe(int type,
- const content::NotificationSource& source,
- const content::NotificationDetails& details) OVERRIDE;
-
- // ExtensionUninstallDialog::Delegate implementation, used for receiving
- // notification about uninstall confirmation dialog selections.
- virtual void ExtensionUninstallAccepted() OVERRIDE;
- virtual void ExtensionUninstallCanceled() OVERRIDE;
-
- private:
- // Helper that lists the current active html pages for an extension.
+ // Helpers that list the current active html pages for an extension.
std::vector<ExtensionPage> GetActivePagesForExtension(
const Extension* extension);
void GetActivePagesForExtensionProcess(
@@ -187,7 +176,7 @@ class ExtensionSettingsHandler : public OptionsPageUIHandler,
content::RenderViewHost* deleting_rvh_;
// We want to register for notifications only after we've responded at least
- // once to the page, otherwise we'd be calling javacsript functions on objects
+ // once to the page, otherwise we'd be calling JavaScript functions on objects
Aaron Boodman 2012/03/14 23:12:44 yay for properly capitalizing this word :)
// that don't exist yet when notifications come in. This variable makes sure
// we do so only once.
bool registered_for_notifications_;

Powered by Google App Engine
This is Rietveld 408576698